@@ -3,7 +3,7 @@
 ## Purpose:     Wx::ActiveX
 ## Author:      Graciliano M. P.
 ## Created:     25/08/2002
-## SVN-ID:      $Id: ActiveX.pm 2364 2008-04-10 04:21:35Z mdootson $
+## SVN-ID:      $Id: ActiveX.pm 2367 2008-04-12 14:05:11Z mdootson $
 ## Copyright:   (c) 2002 - 2008 Graciliano M. P., Mattia Barbon, Mark Dootson
 ## Licence:     This program is free software; you can redistribute it and/or
 ##              modify it under the same terms as Perl itself
@@ -19,15 +19,18 @@ use Wx;
 use vars qw( $AUTOLOAD );
 require Exporter;
 our @ISA = qw( Wx::Window Exporter );
+use XSLoader;
 
-our $VERSION = '0.09'; # Wx::ActiveX Version
+our $VERSION = '0.10'; # Wx::ActiveX Version
 
 our $__wxax_debug;
 our @EXPORT_OK = qw ( wxACTIVEX_CLSID_MOZILLA_BROWSER wxACTIVEX_CLSID_WEB_BROWSER );
 our %EXPORT_TAGS = ( everything => \@EXPORT_OK  );
 our %__wxax_dynamic_loadevent_data = ();
 
-Wx::wx_boot( 'Wx::ActiveX', $VERSION ) ;
+#Wx::wx_boot( 'Wx::ActiveX', $VERSION ) ;
+XSLoader::load 'Wx::ActiveX', $VERSION;
+
 
 # Base ActiveX Event
 push @EXPORT_OK, ( 'EVENTID_ACTIVEX' );
@@ -172,7 +175,7 @@ sub activex_load_activex_event_types {
         $passeventlist->{$key} = $activexname;
     }
     
-    my @codelines = activex_get_event_code($packagename, $namespace, $eventname, $exporttag, 'activex', 1, $passeventlist, 1 );
+    my @codelines = activex_get_event_code($packagename, $namespace, $eventname, $exporttag, 'activex', 1, $passeventlist, 1, 1 );
     my $code = join("\n", @codelines);
     Wx::LogMessage("Wx::ActiveX ActiveX Event Code:\n %s", $code ) if $Wx::ActiveX::__wxax_debug;
     
@@ -202,7 +205,7 @@ sub activex_load_standard_event_types {
         $passeventlist->{$key} = $events->{$shortkey};
     }
     
-    my @codelines = activex_get_event_code($packagename, $namespace, $eventname, $exporttag, 'standard', 1, $passeventlist, 1 );
+    my @codelines = activex_get_event_code($packagename, $namespace, $eventname, $exporttag, 'standard', 1, $passeventlist, 1, 1 );
     my $code = join("\n", @codelines);
     Wx::LogMessage("Wx::ActiveX Standard Event Code:\n %s", $code ) if $Wx::ActiveX::__wxax_debug;
     eval "$code";
@@ -223,23 +226,25 @@ sub activex_get_class_code {
     my $axinfo = $__wxax_dynamic_loadevent_data{$callingclass}->{activex};
     my $stinfo = $__wxax_dynamic_loadevent_data{$callingclass}->{standard};
     
-    my @standard = GetEventCodeForEventTypes($callingclass,
-                                             $stinfo->{namespace},
-                                             $stinfo->{eventname},
-                                             $stinfo->{exporttag},
-                                             'standard',
-                                             1,
-                                             $stinfo->{events},
-                                             0);
+    my @standard = activex_get_event_code($callingclass,
+                                        $stinfo->{namespace},
+                                        $stinfo->{eventname},
+                                        $stinfo->{exporttag},
+                                        'standard',
+                                        1,
+                                        $stinfo->{events},
+                                        0,
+                                        1);
     
-    my @activex = GetEventCodeForEventTypes($callingclass,
-                                             $axinfo->{namespace},
-                                             $axinfo->{eventname},
-                                             $axinfo->{exporttag},
-                                             'activex',
-                                             1,
-                                             $axinfo->{events},
-                                             0);
+    my @activex = activex_get_event_code($callingclass,
+                                        $axinfo->{namespace},
+                                        $axinfo->{eventname},
+                                        $axinfo->{exporttag},
+                                        'activex',
+                                        1,
+                                        $axinfo->{events},
+                                        0,
+                                        1);
     my $code = join("\n", ( @activex, @standard ) );
     return $code;
 }
@@ -249,7 +254,7 @@ sub activex_get_class_code {
 #---------------------------------
 
 sub activex_get_event_code {
-    my ( $packagename, $namespace, $eventname, $exporttag, $eventtype, $commentcode, $events, $store ) = @_;
+    my ( $packagename, $namespace, $eventname, $exporttag, $eventtype, $commentcode, $events, $store, $foreval ) = @_;
     
     if ($store) {
         my %eventcopy = %$events;
@@ -292,9 +297,6 @@ sub activex_get_event_code {
         $codeline = 'sub ' . $evt_idsub_ex . ' () { ' . $evt_id . ' }';
         push @cl_idsub, $codeline;
         
-        # evt id sub export
-        push @cl_idsub_ex, $evt_idsub_ex;
-        
         # evt sub
         my $subcode;
         if ( $eventtype ne 'activex' ) {
@@ -319,12 +321,12 @@ sub activex_get_event_code {
     my @output = ();
     
     push (@output, q() ) if $commentcode;
-    push (@output, q(#-----------------------------------------------------) ) if $commentcode;
-    push (@output, q(  package ) . $namespace . ';' );
-    push (@output, q(#-----------------------------------------------------) ) if $commentcode;
+    push (@output, q(#-----------------------------------------------------) ) if $commentcode && $foreval;
+    push (@output, q(package ) . $namespace . ';' ) if $foreval;
+    push (@output, q(#-----------------------------------------------------) ) if $commentcode && $foreval;
     
     push (@output, q() ) if $commentcode;
-    push (@output, q(our ( @EXPORT_OK, %EXPORT_TAGS );) );
+    push (@output, q(our ( @EXPORT_OK, %EXPORT_TAGS );) ) if $foreval;
     push (@output, q() ) if $commentcode;
     push (@output, q(# Local Event IDs) ) if $commentcode;
     push (@output, q() ) if $commentcode;
@@ -341,9 +343,6 @@ sub activex_get_event_code {
     push (@output, q(# Event Sub Functions) ) if $commentcode;
     push (@output, q() ) if $commentcode;
     
-    ## always implement base ActiveX funnction
-    #push (@output, q(sub EVT_ACTIVEX ($$$$) { &Wx::ActiveX::EVT_ACTIVEX( @_ ); }) );
-    
     push (@output, @cl_evsub);
     push (@output, q() ) if $commentcode;
     push (@output, q(# Exports & Tags) ) if $commentcode;
@@ -364,17 +363,18 @@ sub activex_get_event_code {
     push (@output, "\t" . 'push @' . 'EXPORT_OK, ( @eventexports ) ;'  );
     push (@output, "\t" . 'push @{ $' . 'EXPORT_TAGS{"' . $exporttag . '"} }, ( @eventexports );'  );
     
-    for ( qw( everything all activex ) ) {
-        my $subst = $_;
-        next if $exporttag eq $subst; # don't import twice
-        push (@output, "\t" . 'push (@{ $' . 'EXPORT_TAGS{"' . $subst . '"} }, ( @eventexports )) if exists $EXPORT_TAGS{"' . $subst . ' "};');
+    if ($foreval) {
+        for ( qw( all activex ) ) {
+            my $subst = $_;
+            next if $exporttag eq $subst; # don't import twice
+            push (@output, "\t" . 'push (@{ $' . 'EXPORT_TAGS{"' . $subst . '"} }, ( @eventexports )) if exists $EXPORT_TAGS{"' . $subst . ' "};');
+        }
     }
     
     push (@output, '}' );
     push (@output, q() ) if $commentcode;
-    
-    push (@output, q(package Wx::ActiveX; # return to base package) );
-    push (@output, q() ) if $commentcode;
+    push (@output, q(package Wx::ActiveX; # return to base package) ) if $foreval;
+    push (@output, q() ) if $commentcode && $foreval;
     
     return @output;
 }
@@ -474,7 +474,7 @@ Wx::ActiveX - ActiveX Control Interface for Wx
 
 =head1 VERSION
 
-Version 0.09
+Version 0.10
 
 =head1 SYNOPSIS
     
@@ -524,6 +524,12 @@ Version 0.09
                                                   $eventname,
                                                   $exporttag,
                                                   \@activexevents );
+    
+    ...
+    
+    EVT_ACTIVEX_ELVIS_ONPROGRESS( $this, $activex,\&on_event_handler );
+    
+    
 
 =head1 DESCRIPTION
 
@@ -532,14 +538,26 @@ The package installs a module in Wx::Demo for reference.
 
 There are some wrapped controls included with the package:
 
-Wx::ActiveX::IE                  Internet Explorer Control
-Wx::ActiveX::Mozilla             Mozilla Browser Control
-Wx::ActiveX::WMPlayer            Windows Media Player
-Wx::ActiveX::ScriptControl       MS Script Control
-Wx::ActiveX::Document            Control Wrapper via Browser
+    Wx::ActiveX::IE                  Internet Explorer Control
+    Wx::ActiveX::Mozilla             Mozilla Browser Control
+    Wx::ActiveX::WMPlayer            Windows Media Player
+    Wx::ActiveX::ScriptControl       MS Script Control
+    Wx::ActiveX::Document            Control Wrapper via Browser
+    Wx::ActiveX::Acrobat             Acrobat ActiveX Control
+    Wx::ActiveX::Flash               Adobe Flash Control
+    Wx::ActiveX::Quicktime           Apple QuickTime ActiveX Control
+
+See the POD for each indvidual control.
+
+There is also a Template producer that will provide code for
+a module given an ActiveX ProgID.
+
+wxactivex_template
+
+or
+
+perl -MWx::ActiveX::Template -e"run_wxactivex_template();"
 
-The current version of Wx::ActiveX::Acrobat is not working.
-You can view and print PDF's using Wx::ActiveX::Document.
 
 =head1 METHODS
 
@@ -550,7 +568,7 @@ Create the ActiveX control.
   PARENT        need to be a Wx::Window object.
   CONTROL_ID    The control ID (PROGID/string).
 
-=over 17
+=over
 
 =item PropVal ( PROP_NAME )
 
@@ -645,7 +663,7 @@ Return a string with all the informations about the ActiveX Control:
 
 =back
 
-=head1= Win32::OLE
+=head1 Win32::OLE
 
 From version 0.5 Wx::ActiveX is compatible with Win32::OLE objects:
 
